@@ -365,7 +365,7 @@ def flatten(unflat: list) -> list:
     '''
     flat = []
     for root in unflat:
-        if isinstance(root, list):
+        if isinstance(root, (list, tuple)):
             flat.extend(flatten(root))
         else:
             flat.append(root)
@@ -427,5 +427,6 @@ def datetime_parse(text: str) -> datetime:
         text = text.replace('+', '-')
     elif ('UTC-' in text) or ('GMT-' in text):
         text = text.replace('-', '+')
-    return parse(text, dayfirst=True)
+    dayfirst = (text[:2] != '20') or (text[4] != '-')
+    return parse(text, dayfirst=dayfirst)
 
